==> cic-eth-0.7.0.tar.gz: cic-eth-0.7.0/cic_eth/db/models/tx.py <==
# standard imports
import datetime

# third-party imports
from sqlalchemy import Column, String, Integer, DateTime, Enum, ForeignKey, Boolean
from sqlalchemy.ext.hybrid import hybrid_method, hybrid_property
#from sqlalchemy.orm import relationship, backref
#from sqlalchemy.ext.declarative import declarative_base

# local imports
from .base import SessionBase
from ..enum import TxTypeEnum
from .otx import Otx


class TxCache(SessionBase):
    __tablename__ = 'tx_cache'

    otx_id = Column(Integer, ForeignKey('otx.id'))
    source_token_address = Column(String(42))
    destination_token_address = Column(String(42))
    sender = Column(String(42))
    recipient = Column(String(42))
    from_value = Column(Integer())
    to_value = Column(Integer())
    block_number = Column(Integer())
    tx_index = Column(Integer())
    date_updated = Column(DateTime, default=datetime.datetime.utcnow)
    date_created = Column(DateTime, default=datetime.datetime.utcnow)


    def __init__(self, tx_hash, sender, recipient, source_token_address, destination_token_address, from_value, to_value, block_number=None, tx_index=None):
        session = TxCache.create_session()
        tx = session.query(Otx).filter(Otx.tx_hash==tx_hash).first()
        if tx == None:
            raise FileNotFoundError('outgoing transaction record unknown {} (add a Tx first)'.format(tx_hash))
        self.otx_id = tx.id

        if tx == None:
            raise ValueError('tx hash {} (outgoing: {}) not found'.format(tx_hash, outgoing))
        session.close()

        self.sender = sender
        self.recipient = recipient
        self.source_token_address = source_token_address
        self.destination_token_address = destination_token_address
        self.from_value = from_value
        self.to_value = to_value
        self.block_number = block_number
        self.tx_index = tx_index


    @staticmethod
    def load():
        session = SessionBase.create_session()
        txc = session.query(TxCache).order_by(TxCache.block_number.desc(), TxCache.tx_index.desc()).first()
        session.close()
        return txc

==> cic-eth-0.8.6.tar.gz: cic-eth-0.8.6/cic_eth/db/models/tx.py <==
# standard imports
import datetime

# third-party imports
from sqlalchemy import Column, String, Integer, DateTime, Enum, ForeignKey, Boolean
from sqlalchemy.ext.hybrid import hybrid_method, hybrid_property
#from sqlalchemy.orm import relationship, backref
#from sqlalchemy.ext.declarative import declarative_base

# local imports
from .base import SessionBase
from ..enum import TxTypeEnum
from .otx import Otx


class TxCache(SessionBase):
    __tablename__ = 'tx_cache'

    otx_id = Column(Integer, ForeignKey('otx.id'))
    source_token_address = Column(String(42))
    destination_token_address = Column(String(42))
    sender = Column(String(42))
    recipient = Column(String(42))
    from_value = Column(Integer())
    to_value = Column(Integer())
    block_number = Column(Integer())
    tx_index = Column(Integer())
    date_created = Column(DateTime, default=datetime.datetime.utcnow)
    date_updated = Column(DateTime, default=datetime.datetime.utcnow)
    date_checked = Column(DateTime, default=datetime.datetime.utcnow)


    def check(self):
        self.date_checked = datetime.datetime.now()


    def __init__(self, tx_hash, sender, recipient, source_token_address, destination_token_address, from_value, to_value, block_number=None, tx_index=None):
        session = SessionBase.create_session()
        tx = session.query(Otx).filter(Otx.tx_hash==tx_hash).first()
        if tx == None:
            session.close()
            raise FileNotFoundError('outgoing transaction record unknown {} (add a Tx first)'.format(tx_hash))
        self.otx_id = tx.id

        if tx == None:
            session.close()
            raise ValueError('tx hash {} (outgoing: {}) not found'.format(tx_hash, outgoing))
        session.close()

        self.sender = sender
        self.recipient = recipient
        self.source_token_address = source_token_address
        self.destination_token_address = destination_token_address
        self.from_value = from_value
        self.to_value = to_value
        self.block_number = block_number
        self.tx_index = tx_index
        # not automatically set in sqlite, it seems:
        self.date_created = datetime.datetime.now()
        self.date_updated = self.date_created
        self.date_checked = self.date_checked


    @staticmethod
    def load():
        session = SessionBase.create_session()
        q = session.query(TxCache)
        q = q.order_by(TxCache.block_number.desc(), TxCache.tx_index.desc())
        txc = q.first()
        session.close()
        return txc
